// Function to add a product to the cart
function addToCart(modelData) {
  console.log("Adding to cart:", modelData);

  // Retrieve the cart from localStorage
  let cart = JSON.parse(localStorage.getItem("cart")) || [];

  // Check if the item is already in the cart
  const existingItemIndex = cart.findIndex(
    (item) => item.name === modelData.name
  );

  if (existingItemIndex === -1) {
    // Initialize quantity and add to cart
    modelData.quantity = 1;
    cart.push(modelData);
  } else {
    // Increment quantity if the item already exists
    cart[existingItemIndex].quantity += 1;
  }

  // Save updated cart to localStorage
  localStorage.setItem("cart", JSON.stringify(cart));
  console.log("Updated cart:", cart);

  alert(`${modelData.name} added to the cart!`);
  console.log("Updated cart:", JSON.parse(localStorage.getItem("cart")));
}

// Function to render cart items in the cart section
// Function to render cart items in the cart section
function renderCartItems() {
  const cartItemsContainer = document.getElementById("cartItemsContainer");
  const orderSummary = document.getElementById("orderSummary");
  const selectedCurrency = document.getElementById("currencySelect").value;  // Get selected currency

  // Get cart data from localStorage (or use an empty array if none exists)
  const cart = JSON.parse(localStorage.getItem("cart")) || [];

  // Clear the current cart content
  cartItemsContainer.innerHTML = "";

  // If cart is empty, display a message
  if (cart.length === 0) {
    cartItemsContainer.innerHTML = "<li>Your cart is empty</li>";
    orderSummary.innerHTML = `
        <li><span>Sub-total</span><span id="total">$0.00</span></li>
        <li><span>Pick Up</span><span>FREE</span></li>
        <li><span>HST</span><span>3% of Total</span></li>
        <li><span>Grand Total</span><span id="grandtotal">$0.00</span></li>
      `;
    return;
  }

  // Variable to calculate totals
  let total = 0;

  // Loop through each product in the cart
  cart.forEach((product, index) => {
    let productLeftPrice = product.usdLeftPrice;  // Default price in USD
    let productRightPrice = product.usdRightPrice;

    // Update prices based on selected currency
    if (selectedCurrency === "USD") {
      productLeftPrice = product.usdLeftPrice;
      productRightPrice = product.usdRightPrice;
    } else if (selectedCurrency === "CAD") {
      productLeftPrice = product.cadLeftPrice;
      productRightPrice = product.cadRightPrice;
    }

    // Add the product to the cart table
    cartItemsContainer.innerHTML += `
      <div class="cart-item">
        <div class="cart_product_item">
          <div class="item_image">
            <img src="assets/images/about/turbomelett.png" alt="${product.name}" />
          </div>
          <div class="item_content">
            <h3 class="item_title">${product.name}</h3>
            <a class="item_brand" href="cart.html">Added</a>
          </div>
        </div>
        <div class="cart-details">
          <div class="cart-price">
            <span class="title_text">Price</span>
            <span class="price_text">${productLeftPrice}</span>
          </div>
          <div class="cart-quantity">
            <div class="quantity_form">
              <button type="button" class="input_number_decrement" onclick="updateQuantity(${index}, 'decrement')">
                <i class="fa-regular fa-minus"></i>
              </button>
              <input class="input_number" type="text" value="${product.quantity}" id="quantity-${index}" />
              <button type="button" class="input_number_increment" onclick="updateQuantity(${index}, 'increment')">
                <i class="fa-regular fa-plus"></i>
              </button>
            </div>
          </div>
          <div class="cart-subtotal">
            <span class="title_text">Subtotal</span>
            <span class="price_text" id="subtotal-${index}">$${(parseFloat(productLeftPrice.replace("$", "")) * product.quantity).toFixed(2)}</span>
          </div>
          <div class="cart-remove">
            <span class="title_text">Remove</span>
            <button type="button" class="remove_btn" onclick="removeItemFromCart(${index})">
              <i class="fa-regular fa-trash-can"></i>
            </button>
          </div>
        </div>
      </div>
    `;

    // Calculate total price
    total += parseFloat(productLeftPrice.replace("$", "")) * product.quantity;
  });

  // Update the order summary dynamically based on the currency selected
  const hst = (total * 0.03).toFixed(2);
  const grandTotal = (total + parseFloat(hst)).toFixed(2);

  orderSummary.innerHTML = `
      <li><span>Total</span><span id="total">${selectedCurrency} $${total.toFixed(2)}</span></li>
      <li><span>Pick Up</span><span>FREE</span></li>
      <li><span>HST (3%)</span><span>${selectedCurrency} $${hst}</span></li>
      <li><span>Grand Total</span><span id="grandtotal">${selectedCurrency} ${grandTotal}</span></li>
    `;
}

// Event listener for currency change
document.getElementById("currencySelect").addEventListener("change", renderCartItems);

// Call the function to render cart items when the page loads
window.onload = renderCartItems;


// Function to update the quantity of a product in the cart
function updateQuantity(index, action) {
  const cart = JSON.parse(localStorage.getItem("cart")) || [];

  if (action === "increment") {
    cart[index].quantity++;
  } else if (action === "decrement" && cart[index].quantity > 1) {
    cart[index].quantity--;
  }

  // Save the updated cart back to localStorage
  localStorage.setItem("cart", JSON.stringify(cart));

  // Re-render the cart
  renderCartItems();
}

// Function to remove an item from the cart
function removeItemFromCart(index) {
  const cart = JSON.parse(localStorage.getItem("cart")) || [];

  // Remove the item from the cart
  cart.splice(index, 1);

  // Save the updated cart back to localStorage
  localStorage.setItem("cart", JSON.stringify(cart));

  // Re-render the cart
  renderCartItems();
}

// Call the function to render cart items when the page loads
window.onload = renderCartItems;
